@@ -32,11 +32,11 @@ public:
     Akonadi::Server::PimItem createItem(const char *name, const Akonadi::Server::Collection &parent);
     Akonadi::Server::Part createPart(qint64 pimitemId, const QByteArray &partname, const QByteArray &data);
     QByteArray toByteArray(bool enabled);
-    QByteArray toByteArray(Akonadi::Tristate tristate);
-    Akonadi::Protocol::FetchCollectionsResponse listResponse(const Akonadi::Server::Collection &col,
-                                                             bool ancestors = false,
-                                                             bool mimetypes = true,
-                                                             const QStringList &ancestorFetchScope = QStringList());
+    QByteArray toByteArray(Akonadi::Server::Collection::Tristate tristate);
+    Akonadi::Protocol::FetchCollectionsResponsePtr listResponse(const Akonadi::Server::Collection &col,
+                                                                bool ancestors = false,
+                                                                bool mimetypes = true,
+                                                                const QStringList &ancestorFetchScope = QStringList());
     Akonadi::Server::Collection collection(const char *name);
 
     void cleanup();
