@@ -23,7 +23,7 @@
 
 #include "akonadicore_export.h"
 #include "attribute.h"
-#include "exception.h"
+#include "exceptionbase.h"
 #include "tag.h"
 #include "collection.h"
 #include "relation.h"
@@ -531,6 +531,33 @@ public:
      */
     QVector<int> availablePayloadMetaTypeIds() const;
 
+    /**
+     * Sets a path to a file with full payload.
+     *
+     * This method can only be used by Resources and should not be used by Akonadi
+     * clients. Clients should use setPayload() instead.
+     *
+     * Akonadi will not duplicate content of the file in its database but will
+     * instead directly refer to this file. This means that the file must be
+     * persistent (don't use this method with a temporary files), and the Akonadi
+     * resource that owns the storage is responsible for updating the file path
+     * if the file is changed, moved or removed.
+     *
+     * The payload can still be accessed via payload() methods.
+     *
+     * @see setPayload(), setPayloadFromData()
+     * @since 5.6
+     */
+    void setPayloadPath(const QString &filePath);
+
+    /**
+     * Returns path to the payload file set by setPayloadPath()
+     *
+     * If payload was set via setPayload() or setPayloadFromData() then this
+     * method will return a null string.
+     */
+    QString payloadPath() const;
+
     /**
      * Sets the payload object of this PIM item.
      *
@@ -665,6 +692,7 @@ public:
 private:
     //@cond PRIVATE
     friend class ItemCreateJob;
+    friend class ItemCreateJobPrivate;
     friend class ItemModifyJob;
     friend class ItemModifyJobPrivate;
     friend class ItemSync;
@@ -767,7 +795,7 @@ inline T *Item::attribute(Item::CreateOption option)
         }
         //Reuse 5250
         qWarning() << "Found attribute of unknown type" << dummy.type()
-                    << ". Did you forget to call AttributeFactory::registerAttribute()?";
+                   << ". Did you forget to call AttributeFactory::registerAttribute()?";
     }
 
     T *attr = new T();
@@ -786,10 +814,10 @@ inline T *Item::attribute() const
         }
         //reuse 5250
         qWarning() << "Found attribute of unknown type" << dummy.type()
-                    << ". Did you forget to call AttributeFactory::registerAttribute()?";
+                   << ". Did you forget to call AttributeFactory::registerAttribute()?";
     }
 
-    return 0;
+    return nullptr;
 }
 
 template <typename T>
