@@ -53,7 +53,8 @@ class Q_DECL_HIDDEN CollectionDialog::Private
 public:
     Private(QAbstractItemModel *customModel, CollectionDialog *parent, CollectionDialogOptions options)
         : mParent(parent)
-        , mMonitor(0)
+        , mMonitor(nullptr)
+        , mNewSubfolderButton(nullptr)
     {
         // setup GUI
         QVBoxLayout *layout = new QVBoxLayout(mParent);
@@ -251,7 +252,7 @@ bool CollectionDialog::Private::canCreateCollection(const Akonadi::Collection &p
     if ((parentCollection.rights() & Akonadi::Collection::CanCreateCollection)) {
         const QStringList dialogMimeTypeFilter = mParent->mimeTypeFilter();
         const QStringList parentCollectionMimeTypes = parentCollection.contentMimeTypes();
-        Q_FOREACH (const QString &mimetype, dialogMimeTypeFilter) {
+        for (const QString &mimetype : dialogMimeTypeFilter) {
             if (parentCollectionMimeTypes.contains(mimetype)) {
                 return true;
             }
@@ -267,7 +268,7 @@ void CollectionDialog::Private::slotAddChildCollection()
     if (canCreateCollection(parentCollection)) {
         const QString name = QInputDialog::getText(mParent, i18nc("@title:window", "New Folder"),
                              i18nc("@label:textbox, name of a thing", "Name"));
-        if (name.isEmpty()) {
+        if (name.trimmed().isEmpty()) {
             return;
         }
 
@@ -292,7 +293,7 @@ void CollectionDialog::Private::slotCollectionCreationResult(KJob *job)
 
 CollectionDialog::CollectionDialog(QWidget *parent)
     : QDialog(parent)
-    , d(new Private(0, this, CollectionDialog::None))
+    , d(new Private(nullptr, this, CollectionDialog::None))
 {
 }
 
@@ -330,7 +331,7 @@ Akonadi::Collection::List CollectionDialog::selectedCollections() const
     Collection::List collections;
     const QItemSelectionModel *selectionModel = d->mView->selectionModel();
     const QModelIndexList selectedIndexes = selectionModel->selectedIndexes();
-    Q_FOREACH (const QModelIndex &index, selectedIndexes) {
+    for (const QModelIndex &index : selectedIndexes) {
         if (index.isValid()) {
             const Collection collection = index.model()->data(index, EntityTreeModel::CollectionRole).value<Collection>();
             if (collection.isValid()) {
@@ -352,7 +353,7 @@ void CollectionDialog::setMimeTypeFilter(const QStringList &mimeTypes)
     d->mMimeTypeFilterModel->addMimeTypeFilters(mimeTypes);
 
     if (d->mMonitor) {
-        Q_FOREACH (const QString &mimetype, mimeTypes) {
+        for (const QString &mimetype : mimeTypes) {
             d->mMonitor->setMimeTypeMonitored(mimetype);
         }
     }
