@@ -1,6 +1,6 @@
 /*
     Copyright (c) 2008 Thomas McGuire <thomas.mcguire@gmx.net>
-    Copyright (c) 2012 Laurent Montel <montel@kde.org>
+    Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -30,7 +30,6 @@
 #include <QStyleOptionViewItem>
 #include <QAbstractItemView>
 #include <QTreeView>
-#include <QAbstractProxyModel>
 
 #include "entitytreemodel.h"
 #include "collectionstatistics.h"
@@ -59,7 +58,7 @@ public:
     CollectionStatisticsDelegatePrivate(QAbstractItemView *treeView)
         : parent(treeView)
         , drawUnreadAfterFolder(false)
-        , animator(0)
+        , animator(nullptr)
     {
         updateColor();
     }
@@ -129,7 +128,7 @@ bool CollectionStatisticsDelegate::unreadCountShown() const
 void CollectionStatisticsDelegate::setProgressAnimationEnabled(bool enable)
 {
     Q_D(CollectionStatisticsDelegate);
-    if (enable == (d->animator != 0)) {
+    if (enable == (d->animator != nullptr)) {
         return;
     }
     if (enable) {
@@ -138,14 +137,14 @@ void CollectionStatisticsDelegate::setProgressAnimationEnabled(bool enable)
         d->animator = animator;
     } else {
         delete d->animator;
-        d->animator = 0;
+        d->animator = nullptr;
     }
 }
 
 bool CollectionStatisticsDelegate::progressAnimationEnabled() const
 {
     Q_D(const CollectionStatisticsDelegate);
-    return d->animator != 0;
+    return (d->animator != nullptr);
 }
 
 void CollectionStatisticsDelegate::initStyleOption(QStyleOptionViewItem *option,
