@@ -18,7 +18,7 @@
 */
 
 #include "standardactionmanager.h"
-#include "helper_p.h"
+
 #include "actionstatemanager_p.h"
 #include "agentfilterproxymodel.h"
 #include "agentinstancecreatejob.h"
@@ -1374,7 +1374,7 @@ public:
         const bool isItemAction = (type == CopyItemToMenu || type == MoveItemToMenu);
         const bool isCollectionAction = (type == CopyCollectionToMenu || type == MoveCollectionToMenu);
 
-        const bool canContainRequiredMimeTypes = !collection.contentMimeTypes().toSet().intersect(mimeTypes).isEmpty();
+        const bool canContainRequiredMimeTypes = collection.contentMimeTypes().toSet().intersects(mimeTypes);
         const bool canCreateNewItems = (collection.rights() & Collection::CanCreateItem);
 
         const bool canCreateNewCollections = (collection.rights() & Collection::CanCreateCollection);
